@@ -24,7 +24,6 @@ from zope.interface import implementer
 
 from ._base import BoundLoggerBase
 from ._config import _BUILTIN_DEFAULT_PROCESSORS
-from ._utils import until_not_interrupted
 from .processors import JSONRenderer as GenericJSONRenderer
 from .typing import EventDict, WrappedLogger
 
@@ -136,7 +135,7 @@ class ReprWrapper:
     def __init__(self, string: str) -> None:
         self.string = string
 
-    def __eq__(self, other: Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         """
         Check for equality, just for tests.
         """
@@ -199,12 +198,13 @@ class JSONRenderer(GenericJSONRenderer):
 @implementer(ILogObserver)
 class PlainFileLogObserver:
     """
-    Write only the the plain message without timestamps or anything else.
+    Write only the plain message without timestamps or anything else.
 
     Great to just print JSON to stdout where you catch it with something like
     runit.
 
-    :param file: File to print to.
+    Args:
+        file: File to print to.
 
     .. versionadded:: 0.2.0
     """
@@ -214,12 +214,11 @@ class PlainFileLogObserver:
         self._flush = file.flush
 
     def __call__(self, eventDict: EventDict) -> None:
-        until_not_interrupted(
-            self._write,
+        self._write(
             textFromEventDict(eventDict)  # type: ignore[arg-type, operator]
             + "\n",
         )
-        until_not_interrupted(self._flush)
+        self._flush()
 
 
 @implementer(ILogObserver)
@@ -227,10 +226,12 @@ class JSONLogObserverWrapper:
     """
     Wrap a log *observer* and render non-`JSONRenderer` entries to JSON.
 
-    :param ILogObserver observer: Twisted log observer to wrap.  For example
-        :class:`PlainFileObserver` or Twisted's stock `FileLogObserver
-        <https://docs.twisted.org/en/stable/api/
-        twisted.python.log.FileLogObserver.html>`_
+    Args:
+        observer (ILogObserver):
+            Twisted log observer to wrap.  For example
+            :class:`PlainFileObserver` or Twisted's stock `FileLogObserver
+            <https://docs.twisted.org/en/stable/api/
+            twisted.python.log.FileLogObserver.html>`_
 
     .. versionadded:: 0.2.0
     """
@@ -288,8 +289,10 @@ class EventAdapter:
     <https://docs.twisted.org/en/stable/api/twisted.python.log.html#err>`_
     behave as expected.
 
-    :param dictRenderer: Renderer that is used for the actual log message.
-        Please note that structlog comes with a dedicated `JSONRenderer`.
+    Args:
+        dictRenderer:
+            Renderer that is used for the actual log message. Please note that
+            structlog comes with a dedicated `JSONRenderer`.
 
     **Must** be the last processor in the chain and requires a *dictRenderer*
     for the actual formatting as an constructor argument in order to be able to
@@ -298,12 +301,10 @@ class EventAdapter:
 
     def __init__(
         self,
-        dictRenderer: Callable[[WrappedLogger, str, EventDict], str]
-        | None = None,
+        dictRenderer: (
+            Callable[[WrappedLogger, str, EventDict], str] | None
+        ) = None,
     ) -> None:
-        """
-        :param dictRenderer: A processor used to format the log message.
-        """
         self._dictRenderer = dictRenderer or _BUILTIN_DEFAULT_PROCESSORS[-1]
 
     def __call__(
@@ -311,9 +312,9 @@ class EventAdapter:
     ) -> Any:
         if name == "err":
             # This aspires to handle the following cases correctly:
-            #   - log.err(failure, _why='event', **kw)
-            #   - log.err('event', **kw)
-            #   - log.err(_stuff=failure, _why='event', **kw)
+            #   1. log.err(failure, _why='event', **kw)
+            #   2. log.err('event', **kw)
+            #   3. log.err(_stuff=failure, _why='event', **kw)
             _stuff, _why, eventDict = _extractStuffAndWhy(eventDict)
             eventDict["event"] = _why
 
