@@ -5,15 +5,14 @@
 
 import pytest
 
-from pretend import raiser, stub
-
 from structlog import get_context
 from structlog._base import BoundLoggerBase
 from structlog._config import _CONFIG
 from structlog.exceptions import DropEvent
 from structlog.processors import KeyValueRenderer
 from structlog.testing import ReturnLogger
-from tests.utils import CustomError
+
+from .helpers import CustomError, raiser, stub
 
 
 def build_bl(logger=None, processors=None, context=None):
